@@ -25,13 +25,23 @@ from orchid.native_well_adapter import NativeWellAdapter
 from orchid.native_monitor_curve_facade import NativeMonitorCurveFacade
 from orchid.project_loader import ProjectLoader
 import orchid.project_units as project_units
+import orchid.unit_system as units
 
 # noinspection PyUnresolvedReferences
-from Orchid.FractureDiagnostics import IWell
+from Orchid.FractureDiagnostics import IWell, UnitSystem
 # noinspection PyUnresolvedReferences
 import UnitsNet
 
 
+def as_unit_system(net_unit_system: UnitSystem):
+    if net_unit_system == UnitSystem.USOilfield():
+        return units.UsOilfield
+    elif net_unit_system == UnitSystem.Metric():
+        return units.Metric
+    else:
+        raise ValueError(f'Unrecognized unit system: {net_unit_system}')
+
+
 class Project(dna.DotNetAdapter):
     """Adapts a .NET `IProject` to a Pythonic interface."""
 
@@ -48,6 +58,7 @@ class Project(dna.DotNetAdapter):
         self._wells = []
 
     name = dna.dom_property('name', 'The name of this project.')
+    project_units = dna.transformed_dom_property('project_units', 'The project unit system.', as_unit_system)
     wells = dna.transformed_dom_property_iterator('wells', 'An iterator of all the wells in this project.',
                                                   NativeWellAdapter)
 
@@ -59,22 +70,6 @@ class Project(dna.DotNetAdapter):
         result = list(map(tuple, self._project_loader.native_project().PlottingSettings.GetDefaultWellColors()))
         return result
 
-    def unit(self, physical_quantity):
-        """
-        Return the abbreviation for the specified `physical_quantity` of this project.
-        :param physical_quantity: The name of the physical quantity.
-        :return: The abbreviation of the specified physical quantity.
-        """
-        return project_units.unit(self._project_loader.native_project(), physical_quantity)
-
-    def wells_by_name(self, name) -> Iterable[IWell]:
-        """
-        Return all the wells in this project with the specified name.
-        :param name: The name of the well(s) of interest.
-        :return: A list of all the wells in this project.
-        """
-        return toolz.filter(lambda w: name == w.name, self.wells)
-
     def monitor_curves(self) -> Iterable[NativeMonitorCurveFacade]:
         """
             Return a sequence of well time series for this project.
@@ -87,3 +82,19 @@ class Project(dna.DotNetAdapter):
                              self._project_loader.native_project().WellTimeSeriesList.Items)
         else:
             return []
+
+    def unit_abbreviation(self, physical_quantity):
+        """
+        Return the abbreviation for the specified `physical_quantity` of this project.
+        :param physical_quantity: The name of the physical quantity.
+        :return: The abbreviation of the specified physical quantity.
+        """
+        return project_units.unit_abbreviation(self._project_loader.native_project(), physical_quantity)
+
+    def wells_by_name(self, name) -> Iterable[IWell]:
+        """
+        Return all the wells in this project with the specified name.
+        :param name: The name of the well(s) of interest.
+        :return: A list of all the wells in this project.
+        """
+        return toolz.filter(lambda w: name == w.name, self.wells)
