@@ -52,7 +52,7 @@ def temperature_unit(net_project):
     return UnitsNet.Temperature.GetAbbreviation(net_project.ProjectUnits.TemperatureUnit)
 
 
-def unit(net_project, physical_quantity):
+def unit_abbreviation(net_project, physical_quantity):
     """
     Return the abbreviation for the specified `physical_quantity` of this project.
     :param net_project: The .NET project to query
@@ -66,4 +66,8 @@ def unit(net_project, physical_quantity):
                              'proppant concentration': proppant_concentration_unit,
                              'temperature': temperature_unit}
 
-    return quantity_function_map[physical_quantity](net_project)
+    try:
+        physical_quantity_name = physical_quantity.value.name
+    except AttributeError:
+        physical_quantity_name = physical_quantity
+    return quantity_function_map[physical_quantity_name](net_project)
